@@ -2,7 +2,7 @@
 # ---------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2006 Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2006/05/01, v3.000.008, generateReports.pl for ASNMTAP::Applications making Asnmtap v3.000.xxx compatible
+# 2006/06/01, v3.000.009, generateReports.pl for ASNMTAP::Applications making Asnmtap v3.000.xxx compatible
 # ---------------------------------------------------------------------------------------------------------
 
 use strict;
@@ -18,7 +18,7 @@ use Getopt::Long;
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Asnmtap::Applications v3.000.008;
+use ASNMTAP::Asnmtap::Applications v3.000.009;
 use ASNMTAP::Asnmtap::Applications qw(:APPLICATIONS &call_system
 
                                       $REPORTDIR
@@ -40,16 +40,16 @@ use vars qw($opt_y $opt_m $opt_d $opt_a $opt_u  $opt_V $opt_h $opt_D $PROGNAME);
 
 $PROGNAME       = "generateReports.pl";
 my $prgtext     = "Generate Reports for the '$APPLICATION'";
-my $version     = '3.000.008';
+my $version     = '3.000.009';
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 my $debug       = 0;                                            # default
 my $daysAfter   = 3;                                            # default
 
-my $currentYear = ((localtime)[5])+1900;                        # default
-my $currentMonth= ((localtime)[4])+1;                           # default
-my $currentDay  = ((localtime)[3]);                             # default
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+my ($currentYear, $currentMonth, $currentDay) = ( ((localtime)[5] + 1900), ((localtime)[4] + 1), (localtime)[3] );
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
